diff -Nru diffoscope-81/debian/control diffoscope-81b/debian/control
--- diffoscope-81/debian/control	2017-03-27 17:21:17.000000000 +0200
+++ diffoscope-81b/debian/control	2017-03-30 13:33:49.076783920 +0200
@@ -25,6 +25,7 @@
  ghostscript <!nocheck>,
  giflib-tools <!nocheck>,
  imagemagick <!nocheck>,
+ libarchive-tools <!nocheck>,
  libjs-jquery <!nocheck>,
  libjs-jquery-hotkeys <!nocheck>,
  libjs-jquery-isonscreen <!nocheck>,
diff -Nru diffoscope-81/diffoscope/comparators/zip.py diffoscope-81b/diffoscope/comparators/zip.py
--- diffoscope-81/diffoscope/comparators/zip.py	2017-03-27 17:21:17.000000000 +0200
+++ diffoscope-81b/diffoscope/comparators/zip.py	2017-03-30 15:26:33.402489744 +0200
@@ -51,6 +51,12 @@
         return ['zipinfo', '-v', self.path]
 
 
+class BsdtarVerbose(Command):
+    @tool_required('bsdtar')
+    def cmdline(self):
+        return ['bsdtar', '-tvf', self.path]
+
+
 class ZipDirectory(Directory, ArchiveMember):
     def __init__(self, archive, member_name):
         ArchiveMember.__init__(self, archive, member_name)
@@ -104,7 +110,8 @@
 
     def compare_details(self, other, source=None):
         zipinfo_difference = Difference.from_command(Zipinfo, self.path, other.path) or \
-                             Difference.from_command(ZipinfoVerbose, self.path, other.path)
+                             Difference.from_command(ZipinfoVerbose, self.path, other.path) or \
+                             Difference.from_command(BsdtarVerbose, self.path, other.path)
         return [zipinfo_difference]
 
 
@@ -155,5 +162,6 @@
 
     def compare_details(self, other, source=None):
         zipinfo_difference = Difference.from_command(MozillaZipinfo, self.path, other.path) or \
-                             Difference.from_command(MozillaZipinfoVerbose, self.path, other.path)
+                             Difference.from_command(MozillaZipinfoVerbose, self.path, other.path) or \
+                             Difference.from_command(BsdtarVerbose, self.path, other.path)
         return [zipinfo_difference]
diff -Nru diffoscope-81/diffoscope/external_tools.py diffoscope-81b/diffoscope/external_tools.py
--- diffoscope-81/diffoscope/external_tools.py	2017-03-27 17:21:17.000000000 +0200
+++ diffoscope-81b/diffoscope/external_tools.py	2017-03-30 13:51:01.032699243 +0200
@@ -20,6 +20,12 @@
 EXTERNAL_TOOLS = {
     'apktool': {
         'debian': 'apktool',
+        'arch': 'libarchive',
+        'Fedora': 'bsdtar',
+        'FreeBSD': 'libarchive',
+    },
+    'bsdtar': {
+        'debian': 'libarchive-tools',
     },
     'bzip2': {
         'debian': 'bzip2',
diff -Nru diffoscope-81/tests/comparators/test_zip.py diffoscope-81b/tests/comparators/test_zip.py
--- diffoscope-81/tests/comparators/test_zip.py	2017-03-27 17:21:17.000000000 +0200
+++ diffoscope-81b/tests/comparators/test_zip.py	2017-03-30 14:52:54.633674945 +0200
@@ -28,6 +28,7 @@
 
 zip1 = load_fixture('test1.zip')
 zip2 = load_fixture('test2.zip')
+zip3 = load_fixture('test3.zip')
 mozzip1 = load_fixture('test1.mozzip')
 mozzip2 = load_fixture('test2.mozzip')
 
@@ -43,6 +44,10 @@
 def differences(zip1, zip2):
     return zip1.compare(zip2).details
 
+@pytest.fixture
+def differences2(zip1, zip3):
+    return zip1.compare(zip3).details
+
 @skip_unless_tools_exist('zipinfo')
 def test_metadata(differences):
     expected_diff = get_data('zip_zipinfo_expected_diff')
@@ -55,6 +60,11 @@
     expected_diff = get_data('text_ascii_expected_diff')
     assert differences[1].unified_diff == expected_diff
 
+@skip_unless_tools_exist('zipinfo', 'bsdtar')
+def test_extra_fields(differences2):
+    expected_diff = get_data('zip_bsdtar_expected_diff')
+    assert differences2[0].unified_diff == expected_diff
+
 @skip_unless_tools_exist('zipinfo')
 def test_compare_non_existing(monkeypatch, zip1):
     assert_non_existing(monkeypatch, zip1)
Binary files diffoscope-81/tests/data/test3.zip and diffoscope-81b/tests/data/test3.zip differ
diff -Nru diffoscope-81/tests/data/zip_bsdtar_expected_diff diffoscope-81b/tests/data/zip_bsdtar_expected_diff
--- diffoscope-81/tests/data/zip_bsdtar_expected_diff	1970-01-01 01:00:00.000000000 +0100
+++ diffoscope-81b/tests/data/zip_bsdtar_expected_diff	2017-03-30 14:45:00.444623754 +0200
@@ -0,0 +1,4 @@
+@@ -1,2 +1,2 @@
+ drwxr-xr-x  0 1000   1000        0 Jun 24  2015 dir/
+--rw-r--r--  0 1000   1000      446 Jun 24  2015 dir/text
++-rw-r--r--  0 1000   1000      446 Sep 10  2004 dir/text
